@@ -99,7 +99,11 @@ def generate_mastersnapshot(mastersnapshot):
             logger.error("No nodes in snapshot to be backed up!...")
             return snapshot_data
         snapshot_data = mastersnapshot_fns[snapshot_type](mastersnapshot)
-    logger.info('Snapshot: %s', snapshot_data)
+    # logger.info('Snapshot: %s', snapshot_data)
+    logger.info('\tSnapshot:')
+    for key,value in snapshot_data.items():
+        logger.info('\t%s:%s', key, json.dumps(value))
+    
     return snapshot_data
 
 
@@ -157,14 +161,15 @@ def mastersnapshots_used_in_mastertests_filesystem(container):
     The configuration of the default path is configured in config.ini.
     """
     snapshots = []
-    logger.info("Starting to get list of mastersnapshots used in test files.")
+    # logger.info("Starting to get list of mastersnapshots used in test files.")
     reporting_path = config_value('REPORTING', 'reportOutputFolder')
     json_dir = '%s/%s/%s' % (framework_dir(), reporting_path, container)
-    logger.info(json_dir)
+    # logger.info(json_dir)
     # Only get list of mastertest files.
     test_files = get_json_files(json_dir, MASTERTEST)
-    logger.info('\n'.join(test_files))
+    # logger.info('\n'.join(test_files))
     for test_file in test_files:
+        logger.info('\tMASTERTEST:%s', test_file)
         test_json_data = json_from_file(test_file)
         if test_json_data:
             snapshot = test_json_data['masterSnapshot'] if 'masterSnapshot' in test_json_data else ''
@@ -185,10 +190,11 @@ def generate_container_mastersnapshots_filesystem(container):
     if not snapshot_files:
         logger.error("No mastersnapshot files in %s, exiting!...", snapshot_dir)
         return snapshots_status
-    logger.info('\n'.join(snapshot_files))
+    # logger.info('\n'.join(snapshot_files))
     snapshots = mastersnapshots_used_in_mastertests_filesystem(container)
     populated = []
     for snapshot_file in snapshot_files:
+        logger.info('\tMASTERSNAPSHOT:%s', snapshot_file)
         parts = snapshot_file.rsplit('/', 1)
         if parts[-1] in snapshots and parts[-1] not in populated:
             # Take the snapshot and crawl for the  resource types.
@@ -328,8 +334,11 @@ def generate_container_mastersnapshots(container, dbsystem=True):
     This function is starting point for mastersnapshot crawler operation.
     The default location for mastersnapshots of the container is the database.
     """
-    logger.critical("MASTERSNAPSHOTS: Generate mastersnapshots for '%s' container from %s",
-                    container, "the database." if dbsystem  else "file system.")
+    # logger.critical("MASTERSNAPSHOTS: Generate mastersnapshots for '%s' container from %s",
+    #                 container, "the database." if dbsystem  else "file system.")
+    logger.critical("MASTERSNAPSHOTS:")
+    logger.critical("\tCollection: %s,  Type: %s",
+                    container, "DATABASE" if dbsystem  else "FILESYSTEM")
     if dbsystem:
         return generate_container_mastersnapshots_database(container)
     else:
