@@ -31,12 +31,12 @@ def hcl_to_json(file_path):
     json_data = {}
     try:
         with open(file_path, 'r') as fp:
-            json_data = hcl.load(fp)
-    except:
+            json_data = hcl2.load(fp)
+            json_data = remove_list_from_values(json_data)
+    except Exception:
         try:
             with open(file_path, 'r') as fp:
-                json_data = hcl2.load(fp)
-                json_data = remove_list_from_values(json_data)
+                json_data = hcl.load(fp)
         except Exception as e:
             logger.error("Failed to convert hcl to json data, file: %s , error: %s", file_path, str(e))
 
